[patch] fortran/*.[ch]: Fix comment typos and follow spelling conventions.

Kazu Hirata kazu@cs.umass.edu
Sun Jan 23 14:37:00 GMT 2005


Hi,

Committed as obvious.

Kazu Hirata

2005-01-23  Kazu Hirata  <kazu@cs.umass.edu>

	* data.c, dependency.c, f95-lang.c, io.c, trans-array.c,
	trans-decl.c, trans-expr.c, trans-intrinsic.c, trans-io.c,
	trans-stmt.c, trans-types.c, trans.h: Fix comment typos.
	Follow spelling conventions.

Index: data.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/data.c,v
retrieving revision 1.10
diff -u -d -p -r1.10 data.c
--- data.c	16 Sep 2004 16:00:41 -0000	1.10
+++ data.c	23 Jan 2005 14:24:49 -0000
@@ -1,5 +1,5 @@
 /* Supporting functions for resolving DATA statement.
-   Copyright (C) 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
    Contributed by Lifang Zeng <zlf605@hotmail.com>
 
 This file is part of GCC.
@@ -26,7 +26,7 @@ Software Foundation, 59 Temple Place - S
    during resolveing DATA statement. Refer to check_data_variable and
    traverse_data_list in resolve.c.
                                                                                
-   The complexity exists in the handleing of array section, implied do
+   The complexity exists in the handling of array section, implied do
    and array of struct appeared in DATA statement.
                                                                                
    We call gfc_conv_structure, gfc_con_array_array_initializer,
Index: dependency.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/dependency.c,v
retrieving revision 1.5
diff -u -d -p -r1.5 dependency.c
--- dependency.c	16 Sep 2004 16:00:41 -0000	1.5
+++ dependency.c	23 Jan 2005 14:24:50 -0000
@@ -1,5 +1,5 @@
 /* Dependency analysis
-   Copyright (C) 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 2000, 2001, 2002, 2005 Free Software Foundation, Inc.
    Contributed by Paul Brook <paul@nowt.org>
 
 This file is part of GCC.
@@ -382,7 +382,7 @@ get_deps (mpz_t x1, mpz_t x2, mpz_t y)
    (l_start:l_end:l_stride) -> (0:no_of_elements)
    (r_start:r_end:r_stride) -> (X1:X2)
    Where r_end is implicit as both sections must have the same number of
-   elelments.
+   elements.
    Returns 0 on success, 1 of the transformation failed.  */
 /* TODO: Should this be (0:no_of_elements-1) */
 
Index: f95-lang.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/f95-lang.c,v
retrieving revision 1.29
diff -u -d -p -r1.29 f95-lang.c
--- f95-lang.c	18 Jan 2005 12:11:47 -0000	1.29
+++ f95-lang.c	23 Jan 2005 14:24:50 -0000
@@ -779,7 +779,7 @@ gfc_init_builtin_functions (void)
 
 #include "mathbuiltins.def"
 
-  /* We define these seperately as the fortran versions have different
+  /* We define these separately as the fortran versions have different
      semantics (they return an integer type) */
   gfc_define_builtin ("__builtin_floor", mfunc_double[0], 
 		      BUILT_IN_FLOOR, "floor", true);
Index: io.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/io.c,v
retrieving revision 1.18
diff -u -d -p -r1.18 io.c
--- io.c	18 Jan 2005 12:11:52 -0000	1.18
+++ io.c	23 Jan 2005 14:24:50 -0000
@@ -1098,7 +1098,7 @@ gfc_resolve_open (gfc_open * open)
 }
 
 
-/* Match an OPEN statmement.  */
+/* Match an OPEN statement.  */
 
 match
 gfc_match_open (void)
@@ -1178,7 +1178,7 @@ gfc_free_close (gfc_close * close)
 }
 
 
-/* Match elements of a CLOSE statment.  */
+/* Match elements of a CLOSE statement.  */
 
 static match
 match_close_element (gfc_close * close)
@@ -1425,7 +1425,7 @@ gfc_match_rewind (void)
 }
 
 
-/******************** Data Transfer Statments *********************/
+/******************** Data Transfer Statements *********************/
 
 typedef enum
 { M_READ, M_WRITE, M_PRINT, M_INQUIRE }
Index: trans-decl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-decl.c,v
retrieving revision 1.49
diff -u -d -p -r1.49 trans-decl.c
--- trans-decl.c	25 Nov 2004 11:13:35 -0000	1.49
+++ trans-decl.c	23 Jan 2005 14:24:52 -0000
@@ -1,5 +1,5 @@
 /* Backend function setup
-   Copyright (C) 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
    Contributed by Paul Brook
 
 This file is part of GCC.
@@ -1998,7 +1998,7 @@ gfc_create_module_variable (gfc_symbol *
       internal_error ("module symbol %s in wrong namespace", sym->name);
     }
 
-  /* Only output variables and array valued parametes.  */
+  /* Only output variables and array valued parameters.  */
   if (sym->attr.flavor != FL_VARIABLE
       && (sym->attr.flavor != FL_PARAMETER || sym->attr.dimension == 0))
     return;
Index: trans-expr.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-expr.c,v
retrieving revision 1.36
diff -u -d -p -r1.36 trans-expr.c
--- trans-expr.c	22 Jan 2005 19:20:01 -0000	1.36
+++ trans-expr.c	23 Jan 2005 14:24:52 -0000
@@ -1194,7 +1194,7 @@ gfc_conv_function_call (gfc_se * se, gfc
       gfc_add_block_to_block (&se->pre, &parmse.pre);
       gfc_add_block_to_block (&se->post, &parmse.post);
 
-      /* Character strings are passed as two paramarers, a length and a
+      /* Character strings are passed as two parameters, a length and a
          pointer.  */
       if (parmse.string_length != NULL_TREE)
         stringargs = gfc_chainon_list (stringargs, parmse.string_length);
Index: trans-intrinsic.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-intrinsic.c,v
retrieving revision 1.42
diff -u -d -p -r1.42 trans-intrinsic.c
--- trans-intrinsic.c	16 Jan 2005 16:48:15 -0000	1.42
+++ trans-intrinsic.c	23 Jan 2005 14:24:52 -0000
@@ -2368,7 +2368,7 @@ prepare_arg_info (gfc_se * se, gfc_expr 
    gfc_add_modify_expr(&se->pre, arg, tmp);
    rcs->arg = arg;
 
-   /* Caculate the numbers of bits of exponent, fraction and word  */
+   /* Calculate the numbers of bits of exponent, fraction and word  */
    n = gfc_validate_kind (a1->ts.type, a1->ts.kind, false);
    tmp = build_int_cst (NULL_TREE, gfc_real_kinds[n].digits - 1);
    rcs->fdigits = convert (masktype, tmp);
@@ -2796,7 +2796,7 @@ gfc_conv_intrinsic_function (gfc_se * se
       gfc_conv_intrinsic_conversion (se, expr);
       break;
 
-      /* Integer conversions are handled seperately to make sure we get the
+      /* Integer conversions are handled separately to make sure we get the
          correct rounding mode.  */
     case GFC_ISYM_INT:
       gfc_conv_intrinsic_int (se, expr, FIX_TRUNC_EXPR);
Index: trans-io.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-io.c,v
retrieving revision 1.27
diff -u -d -p -r1.27 trans-io.c
--- trans-io.c	22 Jan 2005 14:37:39 -0000	1.27
+++ trans-io.c	23 Jan 2005 14:24:52 -0000
@@ -1042,7 +1042,7 @@ build_dt (tree * function, gfc_code * co
 
 /* Translate the IOLENGTH form of an INQUIRE statement.  We treat
    this as a third sort of data transfer statement, except that
-   lengths are summed instead of actually transfering any data.  */
+   lengths are summed instead of actually transferring any data.  */
 
 tree
 gfc_trans_iolength (gfc_code * code)
Index: trans-stmt.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-stmt.c,v
retrieving revision 1.21
diff -u -d -p -r1.21 trans-stmt.c
--- trans-stmt.c	18 Jan 2005 12:11:56 -0000	1.21
+++ trans-stmt.c	23 Jan 2005 14:24:52 -0000
@@ -2187,7 +2187,7 @@ gfc_trans_pointer_assign_need_temp (gfc_
       e<i> = f<i>
       g<i> = h<i>
     end forall
-   (where e,f,g,h<i> are arbitary expressions possibly involving i)
+   (where e,f,g,h<i> are arbitrary expressions possibly involving i)
    Translates to:
     count = ((end + 1 - start) / staride)
     masktmp(:) = maskexpr(:)
@@ -3082,7 +3082,7 @@ gfc_trans_cycle (gfc_code * code)
 }
 
 
-/* EXIT a DO loop. Similair to CYCLE, but now the label is in
+/* EXIT a DO loop. Similar to CYCLE, but now the label is in
    TREE_VALUE (backend_decl) of the gfc_code node at the head of the
    loop.  */
 
Index: trans-types.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-types.c,v
retrieving revision 1.36
diff -u -d -p -r1.36 trans-types.c
--- trans-types.c	16 Jan 2005 16:48:16 -0000	1.36
+++ trans-types.c	23 Jan 2005 14:24:53 -0000
@@ -1409,7 +1409,7 @@ gfc_get_derived_type (gfc_symbol * deriv
 	  if (c->pointer)
 	    {
 	      /* Pointers to arrays aren't actually pointer types.  The
-	         descriptors are seperate, but the data is common.  */
+	         descriptors are separate, but the data is common.  */
 	      field_type = gfc_build_array_type (field_type, c->as);
 	    }
 	  else
Index: trans.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans.h,v
retrieving revision 1.21
diff -u -d -p -r1.21 trans.h
--- trans.h	16 Nov 2004 02:02:37 -0000	1.21
+++ trans.h	23 Jan 2005 14:24:53 -0000
@@ -1,5 +1,5 @@
 /* Header for code translation functions
-   Copyright (C) 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
    Contributed by Paul Brook
 
 This file is part of GCC.
@@ -75,7 +75,7 @@ typedef struct gfc_se
 gfc_se;
 
 
-/* Scalarisation State chain.  Created by walking an expression tree before
+/* Scalarization State chain.  Created by walking an expression tree before
    creating the scalarization loops. Then passed as part of a gfc_se structure
    to translate the expression inside the loop.  Note that these chains are
    terminated by gfc_se_terminator, not NULL.  A NULL pointer in a gfc_se
@@ -106,7 +106,7 @@ typedef struct gfc_ss_info
   tree stride[GFC_MAX_DIMENSIONS];
   tree delta[GFC_MAX_DIMENSIONS];
 
-  /* Translation from scalariser dimensions to actual dimensions.
+  /* Translation from scalarizer dimensions to actual dimensions.
      actual = dim[scalarizer]  */
   int dim[GFC_MAX_DIMENSIONS];
 }
@@ -191,7 +191,7 @@ typedef struct gfc_ss
   struct gfc_ss *loop_chain;
   struct gfc_ss *next;
 
-  /* This is used by assignments requiring teporaries. The bits specify which
+  /* This is used by assignments requiring temporaries. The bits specify which
      loops the terms appear in.  This will be 1 for the RHS expressions,
      2 for the LHS expressions, and 3(=1|2) for the temporary.  */
   unsigned useflags:2;
@@ -213,7 +213,7 @@ typedef struct gfc_loopinfo
 
   /* All the SS involved with this loop.  */
   gfc_ss *ss;
-  /* The SS describing the teporary used in an assignment.  */
+  /* The SS describing the temporary used in an assignment.  */
   gfc_ss *temp_ss;
 
   /* The scalarization loop index variables.  */



More information about the Gcc-patches mailing list
Index: trans-array.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-array.c,v
retrieving revision 1.33
diff -u -d -p -r1.33 trans-array.c
--- trans-array.c	18 Jan 2005 12:11:54 -0000	1.33
+++ trans-array.c	23 Jan 2005 14:24:51 -0000
@@ -516,7 +516,7 @@ gfc_trans_allocate_array_storage (gfc_lo
 
 
 /* Generate code to allocate and initialize the descriptor for a temporary
-   array.  This is used for both temporaries needed by the scaparizer, and
+   array.  This is used for both temporaries needed by the scalarizer, and
    functions returning arrays.  Adjusts the loop variables to be zero-based,
    and calculates the loop bounds for callee allocated arrays.
    Also fills in the descriptor, data and offset fields of info if known.
@@ -1305,7 +1305,7 @@ gfc_init_loopinfo (gfc_loopinfo * loop)
 }
 
 
-/* Copies the loop variable info to a gfc_se sructure. Does not copy the SS
+/* Copies the loop variable info to a gfc_se structure. Does not copy the SS
    chain.  */
 
 void
@@ -1534,7 +1534,7 @@ gfc_conv_vector_array_index (gfc_se * se
 
 
 /* Return the offset for an index.  Performs bound checking for elemental
-   dimensions.  Single element references are processed seperately.  */
+   dimensions.  Single element references are processed separately.  */
 
 static tree
 gfc_conv_array_index_offset (gfc_se * se, gfc_ss_info * info, int dim, int i,
@@ -1653,7 +1653,7 @@ gfc_conv_array_ref (gfc_se * se, gfc_arr
   tree fault;
   gfc_se indexse;
 
   /* Handle scalarized references seperately.  */
   if (ar->type != AR_ELEMENT)
     {
       gfc_conv_scalarized_array_ref (se, ar);
@@ -1811,7 +1811,7 @@ gfc_trans_preloop_setup (gfc_loopinfo * 
 	  info->offset = gfc_evaluate_now (info->offset, pblock);
 	}
 
-      /* Remeber this offset for the second loop.  */
+      /* Remember this offset for the second loop.  */
       if (dim == loop->temp_dim - 1)
         info->saved_offset = info->offset;
     }
@@ -3590,7 +3590,7 @@ gfc_conv_expr_descriptor (gfc_se * se, g
       /* A transformational function return value will be a temporary
 	 array descriptor.  We still need to go through the scalarizer
 	 to create the descriptor.  Elemental functions ar handled as
-	 arbitary expressions, i.e. copy to a temporary.  */
+	 arbitrary expressions, i.e. copy to a temporary.  */
       secss = ss;
       /* Look for the SS for this function.  */
       while (secss != gfc_ss_terminator
@@ -3761,7 +3761,7 @@ gfc_conv_expr_descriptor (gfc_se * se, g
          {parm, parmtype, dim} refer to the new one.
          {desc, type, n, secss, loop} refer to the original, which maybe
          a descriptorless array.
-         The bounds of the scaralization are the bounds of the section.
+         The bounds of the scalarization are the bounds of the section.
          We don't have to worry about numeric overflows when calculating
          the offsets because all elements are within the array data.  */
 
@@ -4357,7 +4357,7 @@ gfc_walk_function_expr (gfc_ss * ss, gfc
   if (sym->attr.elemental)
     return gfc_walk_elemental_function_args (ss, expr, GFC_SS_REFERENCE);
 
   /* Scalar functions are OK as these are evaluated outside the scalarisation
      loop.  Pass back and let the caller deal with it.  */
   return ss;
 }
@@ -1653,7 +1653,7 @@ gfc_conv_array_ref (gfc_se * se, gfc_arr
   gfc_se indexse;
 
-  /* Handle scalarized references seperately.  */
+  /* Handle scalarized references separately.  */
   if (ar->type != AR_ELEMENT)
     {
@@ -4357,7 +4357,7 @@ gfc_walk_function_expr (gfc_ss * ss, gfc
     return gfc_walk_elemental_function_args (ss, expr, GFC_SS_REFERENCE);
 
-  /* Scalar functions are OK as these are evaluated outside the scalarisation
+  /* Scalar functions are OK as these are evaluated outside the scalarization
      loop.  Pass back and let the caller deal with it.  */
   return ss;